@@ -77,6 +77,7 @@ typedef unsigned long long UvmGpuPointer;
 // The actual resources remain RM internal and not exposed.
 //
 typedef struct uvmGpuSession_tag      *uvmGpuSessionHandle;      // gpuSessionHandle
+typedef struct uvmGpuDevice_tag       *uvmGpuDeviceHandle;       // gpuDeviceHandle
 typedef struct uvmGpuAddressSpace_tag *uvmGpuAddressSpaceHandle; // gpuAddressSpaceHandle
 typedef struct uvmGpuChannel_tag      *uvmGpuChannelHandle;      // gpuChannelHandle
 typedef struct uvmGpuCopyEngine_tag   *uvmGpuCopyEngineHandle;   // gpuObjectHandle
@@ -89,6 +90,12 @@ typedef struct UvmGpuMemoryInfo_tag
     // Out: Set to TRUE, if the allocation is in sysmem.
     NvBool sysmem;
 
+    // Out: Set to TRUE, if the allocation is a constructed
+    //      under a Device or Subdevice.
+    //      All permutations of sysmem and deviceDescendant are valid.
+    //      !sysmem && !deviceDescendant implies a fabric allocation.
+    NvBool deviceDescendant;
+
     // Out: Page size associated with the phys alloc.
     NvU32 pageSize;
 
@@ -103,6 +110,7 @@ typedef struct UvmGpuMemoryInfo_tag
     NvU64 size;
 
     // Out: Uuid of the GPU to which the allocation belongs.
+    //      This is only valid if deviceDescendant is NV_TRUE.
     //      Note: If the allocation is owned by a device in
     //      an SLI group and the allocation is broadcast
     //      across the SLI group, this UUID will be any one
@@ -323,6 +331,7 @@ typedef struct UvmGpuCaps_tag
     NvBool  *eccErrorNotifier;
     NvBool   bEccEnabled;
     NvU32    sysmemLink;            // UVM_PEER_LINK_TYPE
+    NvU32    sysmemLinkRateMBps;    // See UvmGpuP2PCapsParams::totalLinkLineRateMBps
     NvBool   numaEnabled;
     NvU32    numaNodeId;
 
@@ -413,16 +422,21 @@ typedef struct UvmGpuP2PCapsParams_tag
 {
     NvU32 peerIds[2];               // peerId[i] contains gpu[i]'s peer id of gpu[1 - i]
     NvU32 p2pLink;                  // UVM_PEER_LINK_TYPE
-    NvU32 optimalNvlinkWriteCEs[2]; // optimalNvlinkWriteCEs[i] contains gpu[i]'s optimal 
-                                    // CE for writing to gpu[1 - i] over NVLink. 
-                                    // The CE indexes are valid only if the GPUs are direct 
+    NvU32 optimalNvlinkWriteCEs[2]; // optimalNvlinkWriteCEs[i] contains gpu[i]'s optimal
+                                    // CE for writing to gpu[1 - i] over NVLink.
+                                    // The CE indexes are valid only if the GPUs are direct
                                     // NVLink peers
                                     //
-                                    // The value returned by RM for this field 
+                                    // The value returned by RM for this field
                                     // may change when a GPU is registered with
-                                    // RM for the first time, so UVM needs to 
-                                    // query it again each time a GPU is 
+                                    // RM for the first time, so UVM needs to
+                                    // query it again each time a GPU is
                                     // registered.
+    NvU32 totalLinkLineRateMBps;    // Maximum unidirectional bandwidth between
+                                    // the peers in megabytes per second, not
+                                    // taking into account the protocols
+                                    // overhead. The reported bandwidth for
+                                    // indirect peers is zero.
     NvU32 indirectAccess      : 1;  // Whether peers have a indirect link to communicate.
                                     // On P9 systems, this is true if peers are
                                     // connected to different NPUs that forward the
@@ -519,6 +533,15 @@ typedef struct UvmPmaAllocationOptions_tag
     NvU32 resultFlags;          // valid if the allocation function returns NV_OK
 } UvmPmaAllocationOptions;
 
+//
+// Mirrored in PMA (PMA_PUBLIC_STATS)
+//
+typedef struct UvmPmaStatistics_tag
+{
+    volatile NvU64 numFreePages64k; // PMA-wide free 64KB page count
+    volatile NvU64 numFreePages2m;  // PMA-wide free 2MB pages count
+} UvmPmaStatistics;
+
 /*******************************************************************************
     uvmEventSuspend
     This function will be called by the GPU driver to signal to UVM that the
