@@ -342,6 +342,8 @@ static int nv_drm_load(struct drm_device *dev, unsigned long flags)
 
     nv_dev->pitchAlignment = resInfo.caps.pitchAlignment;
 
+    nv_dev->hasVideoMemory = resInfo.caps.hasVideoMemory;
+
     /* Initialize drm_device::mode_config */
 
     nv_drm_init_mode_config(nv_dev, &resInfo);
@@ -602,6 +604,9 @@ static const struct file_operations nv_drm_fops = {
     .open           = drm_open,
     .release        = drm_release,
     .unlocked_ioctl = drm_ioctl,
+#if defined(CONFIG_COMPAT)
+    .compat_ioctl   = drm_compat_ioctl,
+#endif
 
 #if defined(NV_DRM_ATOMIC_MODESET_AVAILABLE)
     .mmap           = drm_gem_mmap,
@@ -736,7 +741,7 @@ static void nv_drm_register_drm_device(const nv_gpu_info_t *gpu_info)
 {
     struct nv_drm_device *nv_dev = NULL;
     struct drm_device *dev = NULL;
-    struct pci_dev *pdev = gpu_info->os_dev_ptr;
+    struct device *device = gpu_info->os_device_ptr;
 
     DRM_DEBUG(
         "Registering device for NVIDIA GPU ID 0x08%x",
@@ -760,7 +765,7 @@ static void nv_drm_register_drm_device(const nv_gpu_info_t *gpu_info)
 
     /* Allocate DRM device */
 
-    dev = drm_dev_alloc(&nv_drm_driver, &pdev->dev);
+    dev = drm_dev_alloc(&nv_drm_driver, device);
 
     if (dev == NULL) {
         NV_DRM_DEV_LOG_ERR(nv_dev, "Failed to allocate device");
@@ -769,7 +774,9 @@ static void nv_drm_register_drm_device(const nv_gpu_info_t *gpu_info)
 
     dev->dev_private = nv_dev;
     nv_dev->dev = dev;
-    dev->pdev = pdev;
+    if (device->bus == &pci_bus_type) {
+        dev->pdev = to_pci_dev(device);
+    }
 
     /* Register DRM device to DRM sub-system */
 
