@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2015 NVIDIA Corporation
+    Copyright (c) 2015-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -31,7 +31,6 @@
 #include "uvm8_processors.h"
 #include "uvm8_gpu.h"
 #include "uvm8_lock.h"
-#include "nv-kthread-q.h"
 
 // Global state of the uvm driver
 struct uvm_global_struct
@@ -40,13 +39,13 @@ struct uvm_global_struct
     // Note that GPUs are added to this mask as the last step of add_gpu() and
     // removed from it as the first step of remove_gpu() implying that a GPU
     // that's being initialized or deinitialized will not be in it.
-    uvm_processor_mask_t retained_gpus;
+    uvm_global_processor_mask_t retained_gpus;
 
     // Array of the GPUs retained by uvm
-    // Note that GPUs will have ids offset by 1 to accomodate the UVM_CPU_ID (0),
+    // Note that GPUs will have ids offset by 1 to accomodate the UVM_ID_CPU
     // so e.g. gpus[0] will have GPU id = 1.
     // A GPU entry is unused iff it does not exist (is a NULL pointer) in this table.
-    uvm_gpu_t *gpus[UVM_MAX_GPUS];
+    uvm_gpu_t *gpus[UVM_GLOBAL_ID_MAX_GPUS];
 
     // A global RM session (RM client)
     // Created on module load and destroyed on module unload
@@ -129,96 +128,43 @@ NV_STATUS uvm_global_init(void);
 void uvm_global_exit(void);
 
 // Prepare for entry into a system sleep state
-NV_STATUS uvm_suspend(void);
+NV_STATUS uvm_suspend_entry(void);
 
 // Recover after exit from a system sleep state
-NV_STATUS uvm_resume(void);
+NV_STATUS uvm_resume_entry(void);
 
-// Get a gpu by its id.
+// Get a gpu by its global id.
 // Returns a pointer to the GPU object, or NULL if not found.
 //
 // LOCKING: requires that you hold the gpu_table_lock, the global_lock, or have
 // retained the gpu.
-static uvm_gpu_t *uvm_gpu_get(uvm_gpu_id_t gpu_id)
+static uvm_gpu_t *uvm_gpu_get(uvm_global_gpu_id_t gpu_id)
 {
-    UVM_ASSERT_MSG(gpu_id > 0 && gpu_id < UVM_MAX_PROCESSORS, "gpu id %u\n", gpu_id);
-
-    return g_uvm_global.gpus[uvm_gpu_index(gpu_id)];
+    return g_uvm_global.gpus[uvm_global_id_gpu_index(gpu_id)];
 }
 
-static const char *uvm_processor_name(uvm_processor_id_t id)
+// Get a gpu by its processor id.
+// Returns a pointer to the GPU object, or NULL if not found.
+//
+// LOCKING: requires that you hold the gpu_table_lock, the global_lock, or have
+// retained the gpu.
+
+
+
+
+
+
+
+static uvm_gpu_t *uvm_gpu_get_by_processor_id(uvm_processor_id_t id)
 {
-    if (id == UVM_CPU_ID)
-        return "0: CPU";
-    else
-        return uvm_gpu_get(id)->name;
-}
+    uvm_global_gpu_id_t global_id = uvm_global_gpu_id(uvm_id_value(id));
+    uvm_gpu_t *gpu = uvm_gpu_get(global_id);
 
-static uvm_gpu_t *uvm_processor_mask_find_first_gpu(const uvm_processor_mask_t *mask)
-{
-    uvm_gpu_t *gpu;
-    uvm_gpu_id_t gpu_id = uvm_processor_mask_find_first_gpu_id(mask);
-    if (gpu_id == UVM_MAX_PROCESSORS)
-        return NULL;
-
-    gpu = uvm_gpu_get(gpu_id);
-
-    // If there is valid GPU id in the mask, assert that the corresponding
-    // uvm_gpu_t is present. Otherwise it would stop a for_each_gpu_in_mask()
-    // loop pre-maturely. Today, this could only happen in remove_gpu() because
-    // the GPU being removed is deleted from the global table very early.
-    UVM_ASSERT_MSG(gpu, "gpu_id %u\n", gpu_id);
+    UVM_ASSERT(uvm_id_value(gpu->id) == uvm_global_id_value(gpu->global_id));
 
     return gpu;
 }
 
-static uvm_gpu_t *uvm_processor_mask_find_next_gpu(const uvm_processor_mask_t *mask, uvm_gpu_t *gpu)
-{
-    uvm_gpu_id_t gpu_id;
-    if (gpu == NULL)
-        return NULL;
-
-    gpu_id = uvm_processor_mask_find_next_id(mask, gpu->id + 1);
-    if (gpu_id == UVM_MAX_PROCESSORS)
-        return NULL;
-
-    gpu = uvm_gpu_get(gpu_id);
-
-    // See comment in uvm_processor_mask_find_first_gpu().
-    UVM_ASSERT_MSG(gpu, "gpu_id %u\n", gpu_id);
-
-    return gpu;
-}
-
-// Helper to iterate over all GPUs (uvm_gpu_t) set in a mask. DO NOT USE if the current GPU
-// GPUs can be destroyed within the loop or have been already removed from the GPU table.
-#define for_each_gpu_in_mask(gpu, mask)                                 \
-    for (gpu = uvm_processor_mask_find_first_gpu(mask);                 \
-         gpu != NULL;                                                   \
-         gpu = uvm_processor_mask_find_next_gpu(mask, gpu))
-
-// Same as for_each_gpu_in_mask() but also asserts the passed-in rwsem is locked
-#define for_each_gpu_in_mask_with_rwsem(gpu, mask, rwsem)               \
-    for (({uvm_assert_rwsem_locked(rwsem);                              \
-           gpu = uvm_processor_mask_find_first_gpu(mask);});            \
-           gpu != NULL;                                                 \
-           gpu = uvm_processor_mask_find_next_gpu(mask, gpu))
-
-// Same as for_each_gpu_in_mask() but also asserts the passed-in mutex is locked
-#define for_each_gpu_in_mask_with_mutex(gpu, mask, mutex)               \
-    for (({uvm_assert_mutex_locked(mutex);                              \
-           gpu = uvm_processor_mask_find_first_gpu(mask);});            \
-           gpu != NULL;                                                 \
-           gpu = uvm_processor_mask_find_next_gpu(mask, gpu))
-
-// Helper to iterate over all GPUs retained by the UVM driver (across all va spaces)
-#define for_each_global_gpu(gpu) \
-    for_each_gpu_in_mask_with_mutex(gpu, &g_uvm_global.retained_gpus, &g_uvm_global.global_lock)
-
-// Helper to iterate over all GPUs registered in a UVM VA space
-#define for_each_va_space_gpu(gpu, va_space) \
-    for_each_gpu_in_mask_with_rwsem(gpu, &va_space->registered_gpus, &va_space->lock)
-
 // Use these READ_ONCE()/WRITE_ONCE() wrappers when accessing GPU resources
 // in BAR0/BAR1 to detect cases in which GPUs are accessed when UVM is
 // suspended.
@@ -273,4 +219,76 @@ NV_STATUS uvm_global_reset_fatal_error(void);
 // present, just whether system support exists.
 bool uvm_pageable_mem_access_supported(uvm_va_space_t *va_space);
 
+static uvm_gpu_t *uvm_global_processor_mask_find_first_gpu(const uvm_global_processor_mask_t *global_gpus)
+{
+    uvm_gpu_t *gpu;
+    uvm_global_gpu_id_t gpu_id = uvm_global_processor_mask_find_first_gpu_id(global_gpus);
+
+    if (UVM_GLOBAL_ID_IS_INVALID(gpu_id))
+        return NULL;
+
+    gpu = uvm_gpu_get(gpu_id);
+
+    // If there is valid GPU id in the mask, assert that the corresponding
+    // uvm_gpu_t is present. Otherwise it would stop a
+    // for_each_global_gpu_in_mask() loop pre-maturely. Today, this could only
+    // happen in remove_gpu() because the GPU being removed is deleted from the
+    // global table very early.
+    UVM_ASSERT_MSG(gpu, "gpu_id %u\n", uvm_global_id_value(gpu_id));
+
+    return gpu;
+}
+
+static uvm_gpu_t *__uvm_global_processor_mask_find_next_gpu(const uvm_global_processor_mask_t *global_gpus, uvm_gpu_t *gpu)
+{
+    uvm_global_gpu_id_t gpu_id;
+
+    UVM_ASSERT(gpu);
+
+    gpu_id = uvm_global_processor_mask_find_next_id(global_gpus, uvm_global_gpu_id_next(gpu->global_id));
+    if (UVM_GLOBAL_ID_IS_INVALID(gpu_id))
+        return NULL;
+
+    gpu = uvm_gpu_get(gpu_id);
+
+    // See comment in uvm_global_processor_mask_find_first_gpu().
+    UVM_ASSERT_MSG(gpu, "gpu_id %u\n", uvm_global_id_value(gpu_id));
+
+    return gpu;
+}
+
+static uvm_gpu_t *uvm_global_processor_mask_find_next_gpu(const uvm_global_processor_mask_t *global_gpus, uvm_gpu_t *gpu)
+{
+    if (gpu == NULL)
+        return NULL;
+
+    return __uvm_global_processor_mask_find_next_gpu(global_gpus, gpu);
+}
+
+// Helper to iterate over all GPUs in the input mask
+#define for_each_global_gpu_in_mask(gpu, global_mask)                                         \
+    for (gpu = uvm_global_processor_mask_find_first_gpu(global_mask);                         \
+         gpu != NULL;                                                                         \
+         gpu = __uvm_global_processor_mask_find_next_gpu(global_mask, gpu))
+
+// Helper to iterate over all GPUs retained by the UVM driver (across all va spaces)
+#define for_each_global_gpu(gpu)                                                              \
+    for (({uvm_assert_mutex_locked(&g_uvm_global.global_lock);                                \
+           gpu = uvm_global_processor_mask_find_first_gpu(&g_uvm_global.retained_gpus);});    \
+           gpu != NULL;                                                                       \
+           gpu = __uvm_global_processor_mask_find_next_gpu(&g_uvm_global.retained_gpus, gpu))
+
+// Helper which calls uvm_gpu_retain on each GPU in mask
+void uvm_global_mask_retain(const uvm_global_processor_mask_t *mask);
+
+// Helper which calls uvm_gpu_release_locked on each GPU in mask.
+//
+// LOCKING: this function takes and releases the global lock if the input mask
+//          is not empty
+void uvm_global_mask_release(const uvm_global_processor_mask_t *mask);
+
+// Check for ECC errors for all GPUs in a mask
+// Notably this check cannot be performed where it's not safe to call into RM.
+NV_STATUS uvm_global_mask_check_ecc_error(uvm_global_processor_mask_t *gpus);
+
 #endif // __UVM8_GLOBAL_H__
