@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2016-2018 NVIDIA Corporation
+    Copyright (c) 2016-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -42,7 +42,7 @@ void uvm_hal_pascal_arch_init_properties(uvm_gpu_t *gpu)
 
     gpu->utlb_per_gpc_count = uvm_pascal_get_utlbs_per_gpc(gpu);
 
-    gpu->fault_buffer_info.replayable.utlb_count = gpu->gpc_count * gpu->utlb_per_gpc_count;
+    gpu->fault_buffer_info.replayable.utlb_count = gpu->rm_info.gpcCount * gpu->utlb_per_gpc_count;
     {
         uvm_fault_buffer_entry_t *dummy;
         UVM_ASSERT(gpu->fault_buffer_info.replayable.utlb_count <= (1 << (sizeof(dummy->fault_source.utlb_id) * 8)));
@@ -70,9 +70,9 @@ void uvm_hal_pascal_arch_init_properties(uvm_gpu_t *gpu)
 
     // Pascal and Volta require post-invalidate membars to flush out HSHUB. See
     // bug 1975028. GP10x chips do not have HSHUB, so they don't need any.
-    UVM_ASSERT(gpu->architecture == NV2080_CTRL_MC_ARCH_INFO_ARCHITECTURE_GP100);
-    if (gpu->implementation == NV2080_CTRL_MC_ARCH_INFO_IMPLEMENTATION_GP100 ||
-        gpu->implementation == NV2080_CTRL_MC_ARCH_INFO_IMPLEMENTATION_GP000)
+    UVM_ASSERT(gpu->rm_info.gpuArch == NV2080_CTRL_MC_ARCH_INFO_ARCHITECTURE_GP100);
+    if (gpu->rm_info.gpuImplementation == NV2080_CTRL_MC_ARCH_INFO_IMPLEMENTATION_GP100 ||
+        gpu->rm_info.gpuImplementation == NV2080_CTRL_MC_ARCH_INFO_IMPLEMENTATION_GP000)
         gpu->num_hshub_tlb_invalidate_membars = 2;
     else
         gpu->num_hshub_tlb_invalidate_membars = 0;
