@@ -28,6 +28,7 @@
 #include "uvm8_kvmalloc.h"
 #include "uvm8_va_block.h"
 #include "uvm8_va_range.h"
+#include "uvm8_test.h"
 
 // Global cache to allocate the per-VA block prefetch detection structures
 static struct kmem_cache *g_prefetch_info_cache __read_mostly;
@@ -170,7 +171,7 @@ static block_prefetch_info_t *prefetch_info_get_create(uvm_va_block_t *va_block)
         if (!prefetch_info)
             goto fail;
 
-        prefetch_info->last_migration_proc_id = UVM_MAX_PROCESSORS;
+        prefetch_info->last_migration_proc_id = UVM_ID_INVALID;
 
         uvm_va_block_bitmap_tree_init_from_page_count(&prefetch_info->bitmap_tree, num_leaves);
 
@@ -249,8 +250,9 @@ void uvm_perf_prefetch_prenotify_fault_migrations(uvm_va_block_t *va_block,
     const uvm_page_mask_t *resident_mask = NULL;
     const uvm_page_mask_t *thrashing_pages = NULL;
     uvm_va_range_t *va_range = va_block->va_range;
+    uvm_va_space_t *va_space = va_range->va_space;
 
-    uvm_assert_rwsem_locked(&va_range->va_space->lock);
+    uvm_assert_rwsem_locked(&va_space->lock);
 
     if (!g_uvm_perf_prefetch_enable)
         return;
@@ -259,19 +261,20 @@ void uvm_perf_prefetch_prenotify_fault_migrations(uvm_va_block_t *va_block,
     if (!prefetch_info)
         return;
 
-    if (prefetch_info->last_migration_proc_id != new_residency) {
+    if (!uvm_id_equal(prefetch_info->last_migration_proc_id, new_residency)) {
         prefetch_info->last_migration_proc_id = new_residency;
         prefetch_info->fault_migrations_to_last_proc = 0;
     }
 
     prefetch_info->pending_prefetch_pages = 0;
 
-    if (new_residency == UVM_CPU_ID || va_block->gpus[uvm_gpu_index(new_residency)] != NULL)
+    if (UVM_ID_IS_CPU(new_residency) || va_block->gpus[uvm_id_gpu_index(new_residency)] != NULL)
         resident_mask = uvm_va_block_resident_mask_get(va_block, new_residency);
 
     // If this is a first-touch fault and the destination processor is the
     // preferred location, populate the whole VA block
-    if (uvm_processor_mask_empty(&va_block->resident) && new_residency == va_range->preferred_location) {
+    if (uvm_processor_mask_empty(&va_block->resident) &&
+        uvm_id_equal(new_residency, va_range->preferred_location)) {
         uvm_page_mask_region_fill(&prefetch_info->prefetch_pages, uvm_va_block_region_from_block(va_block));
         goto done;
     }
@@ -284,9 +287,9 @@ void uvm_perf_prefetch_prenotify_fault_migrations(uvm_va_block_t *va_block,
     // Get the big page size for the new residency
     // Assume 64K size if the new residency is the CPU or no GPU va space is
     // registered in the current process for this GPU.
-    if (new_residency != UVM_CPU_ID &&
-        uvm_processor_mask_test(&va_range->va_space->registered_gpu_va_spaces, new_residency)) {
-        uvm_gpu_t *gpu = uvm_gpu_get(new_residency);
+    if (UVM_ID_IS_GPU(new_residency) &&
+        uvm_processor_mask_test(&va_space->registered_gpu_va_spaces, new_residency)) {
+        uvm_gpu_t *gpu = uvm_va_space_get_gpu(va_space, new_residency);
         prefetch_info->big_page_size = uvm_va_block_gpu_big_page_size(va_block, gpu);
     }
     else {
@@ -350,7 +353,7 @@ done:
     // TODO: Bug 1765432: prefetching pages that are already mapped on the CPU
     // would trigger a remap, which may cause a large overhead. Therefore,
     // exclude them from the mask.
-    if (new_residency == UVM_CPU_ID) {
+    if (UVM_ID_IS_CPU(new_residency)) {
         uvm_page_mask_and(&va_block_context->scratch_page_mask,
                           resident_mask,
                           &va_block->cpu.pte_bits[UVM_PTE_BITS_CPU_READ]);
