@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2015 NVIDIA Corporation
+    Copyright (c) 2015-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -90,7 +90,7 @@ static bool preferred_location_is_va_range_split_needed(uvm_va_range_t *va_range
     uvm_processor_id_t processor_id;
     UVM_ASSERT(data);
     processor_id = *(uvm_processor_id_t*)data;
-    return (processor_id != va_range->preferred_location);
+    return !uvm_id_equal(processor_id, va_range->preferred_location);
 }
 
 static NV_STATUS preferred_location_unmap_remote_pages(uvm_va_block_t *va_block,
@@ -103,7 +103,7 @@ static NV_STATUS preferred_location_unmap_remote_pages(uvm_va_block_t *va_block,
     uvm_processor_id_t preferred_location = va_range->preferred_location;
     const uvm_page_mask_t *mapped_mask;
 
-    if (preferred_location == UVM_MAX_PROCESSORS || !uvm_processor_mask_test(&va_block->mapped, preferred_location))
+    if (UVM_ID_IS_INVALID(preferred_location) || !uvm_processor_mask_test(&va_block->mapped, preferred_location))
         goto done;
 
     // Read duplication takes precedence over PreferredLocation. No mappings
@@ -163,11 +163,11 @@ static NV_STATUS preferred_location_set(uvm_va_space_t *va_space,
 
     uvm_assert_rwsem_locked_write(&va_space->lock);
 
-    if (preferred_location != UVM_MAX_PROCESSORS) {
+    if (UVM_ID_IS_VALID(preferred_location)) {
         UVM_ASSERT(first_va_range_to_migrate != NULL);
 
         *first_va_range_to_migrate = NULL;
-        preferred_location_is_faultable_gpu = preferred_location != UVM_CPU_ID &&
+        preferred_location_is_faultable_gpu = UVM_ID_IS_GPU(preferred_location) &&
                                               uvm_processor_mask_test(&va_space->faultable_processors,
                                                                       preferred_location);
     }
@@ -188,9 +188,9 @@ static NV_STATUS preferred_location_set(uvm_va_space_t *va_space,
 
         // If we didn't split the ends, check that they match
         if (va_range->node.start < base || va_range->node.end > last_address)
-            UVM_ASSERT(va_range->preferred_location == preferred_location);
+            UVM_ASSERT(uvm_id_equal(va_range->preferred_location, preferred_location));
 
-        if (preferred_location != UVM_MAX_PROCESSORS) {
+        if (UVM_ID_IS_VALID(preferred_location)) {
             const NvU64 start = max(base, va_range->node.start);
             const NvU64 end = min(last_address, va_range->node.end);
 
@@ -247,7 +247,7 @@ NV_STATUS uvm_api_set_preferred_location(const UVM_SET_PREFERRED_LOCATION_PARAMS
 
     // If the CPU is the preferred location, we don't have to find the associated uvm_gpu_t
     if (uvm_uuid_is_cpu(&params->preferredLocation)) {
-        preferred_location_id = UVM_CPU_ID;
+        preferred_location_id = UVM_ID_CPU;
     }
     else {
         // Translate preferredLocation into a live GPU ID, and check that this
@@ -323,7 +323,7 @@ NV_STATUS uvm_api_unset_preferred_location(const UVM_UNSET_PREFERRED_LOCATION_PA
     status = uvm_api_range_type_check(va_space, params->requestedBase, params->length);
 
     if (status == NV_OK)
-        status = preferred_location_set(va_space, params->requestedBase, params->length, UVM_MAX_PROCESSORS, NULL);
+        status = preferred_location_set(va_space, params->requestedBase, params->length, UVM_ID_INVALID, NULL);
     else if (status == NV_WARN_NOTHING_TO_DO)
         status = NV_OK;
 
@@ -400,7 +400,7 @@ static NV_STATUS accessed_by_set(uvm_va_space_t *va_space,
                                  const NvProcessorUuid *processor_uuid,
                                  bool set_bit)
 {
-    uvm_processor_id_t processor_id = UVM_MAX_PROCESSORS;
+    uvm_processor_id_t processor_id = UVM_ID_INVALID;
     uvm_va_range_t *va_range, *va_range_last;
     const NvU64 last_address = base + length - 1;
     bool range_is_sysmem = false;
@@ -421,7 +421,7 @@ static NV_STATUS accessed_by_set(uvm_va_space_t *va_space,
     }
 
     if (uvm_uuid_is_cpu(processor_uuid)) {
-        processor_id = UVM_CPU_ID;
+        processor_id = UVM_ID_CPU;
     }
     else {
         // Translate processor_uuid into a live GPU ID, and check that this GPU
@@ -552,7 +552,7 @@ static NV_STATUS va_block_unset_read_duplication_locked(uvm_va_block_t *va_block
     // and invalidate the rest of copies
 
     // If preferred_location is set and has resident copies, give it preference
-    if (va_range->preferred_location != UVM_MAX_PROCESSORS &&
+    if (UVM_ID_IS_VALID(va_range->preferred_location) &&
         uvm_processor_mask_test(&va_block->resident, va_range->preferred_location)) {
         uvm_page_mask_t *resident_mask = uvm_va_block_resident_mask_get(va_block, va_range->preferred_location);
         bool is_mask_empty = !uvm_page_mask_and(break_read_duplication_pages,
@@ -579,7 +579,7 @@ static NV_STATUS va_block_unset_read_duplication_locked(uvm_va_block_t *va_block
         uvm_page_mask_t *resident_mask;
         bool is_mask_empty;
 
-        if (processor_id == va_range->preferred_location)
+        if (uvm_id_equal(processor_id, va_range->preferred_location))
             continue;
 
         resident_mask = uvm_va_block_resident_mask_get(va_block, processor_id);
@@ -776,7 +776,7 @@ static NV_STATUS system_wide_atomics_set(uvm_va_space_t *va_space, const NvProce
                     continue;
                 }
 
-                uvm_page_mask_complement(non_resident_pages, &va_block->gpus[uvm_gpu_index(gpu->id)]->resident);
+                uvm_page_mask_complement(non_resident_pages, &va_block->gpus[uvm_id_gpu_index(gpu->id)]->resident);
 
                 status = uvm_va_block_revoke_prot(va_block,
                                                   va_block_context,
