@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2015 NVIDIA Corporation
+    Copyright (c) 2015-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -29,6 +29,7 @@
 #include "uvm_ioctl.h"
 #include "uvmtypes.h"
 #include "uvm8_api.h"
+#include "uvm8_test.h"
 
 static struct kmem_cache *g_uvm_range_group_cache __read_mostly;
 static struct kmem_cache *g_uvm_range_group_range_cache __read_mostly;
@@ -78,8 +79,8 @@ static void uvm_range_group_range_destroy(uvm_range_group_range_t *rgr)
 
     list_del(&rgr->range_group_list_node);
 
-    // The VA space should be locked in write mode when this function is called, so we don't need to acquire the
-    // migrated_list lock.
+    // The VA space should be locked in write mode when this function is called,
+    // so we don't need to acquire the migrated_list lock.
     list_del(&rgr->range_group_migrated_list_node);
     kmem_cache_free(g_uvm_range_group_range_cache, rgr);
 }
@@ -183,8 +184,9 @@ static NV_STATUS uvm_range_group_va_range_migrate_block_locked(uvm_va_range_t *v
     uvm_gpu_id_t gpu_id;
     uvm_processor_mask_t map_mask;
 
-    // Unmapping UVM_CPU_ID is guaranteed to never fail
-    (void)uvm_va_block_unmap(va_block, va_block_context, UVM_CPU_ID, region, NULL, NULL);
+    // Unmapping UVM_ID_CPU is guaranteed to never fail
+    status = uvm_va_block_unmap(va_block, va_block_context, UVM_ID_CPU, region, NULL, NULL);
+    UVM_ASSERT(status == NV_OK);
 
     if (uvm_va_range_is_read_duplicate(va_range)) {
         status = uvm_va_block_make_resident_read_duplicate(va_block,
@@ -224,7 +226,7 @@ static NV_STATUS uvm_range_group_va_range_migrate_block_locked(uvm_va_range_t *v
     // 2- Map faultable SetAccessedBy GPUs.
     uvm_processor_mask_and(&map_mask,
                            &va_range->accessed_by,
-                           &va_range->va_space->can_access[va_range->preferred_location]);
+                           &va_range->va_space->can_access[uvm_id_value(va_range->preferred_location)]);
     uvm_processor_mask_andnot(&map_mask, &map_mask, &va_range->uvm_lite_gpus);
 
     for_each_gpu_id_in_mask(gpu_id, &map_mask) {
@@ -318,12 +320,13 @@ NV_STATUS uvm_api_set_range_group(UVM_SET_RANGE_GROUP_PARAMS *params, struct fil
         goto done;
     }
 
-    // If the desired range group is not migratable, any overlapping va_ranges must have a preferred location
+    // If the desired range group is not migratable, any overlapping va_ranges
+    // must have a preferred location
     migratable = uvm_range_group_migratable(range_group);
     va_range_last = NULL;
     uvm_for_each_managed_va_range_in_contig(va_range, va_space, params->requestedBase, last_address) {
         va_range_last = va_range;
-        if (!migratable && va_range->preferred_location == UVM_MAX_PROCESSORS) {
+        if (!migratable && UVM_ID_IS_INVALID(va_range->preferred_location)) {
             status = NV_ERR_INVALID_ADDRESS;
             goto done;
         }
@@ -383,7 +386,8 @@ static NV_STATUS uvm_range_group_prevent_migration(uvm_range_group_t *range_grou
 
     uvm_assert_rwsem_locked(&va_space->lock);
 
-    // Move the range group's migrated_ranges list to the local_migrated_ranges list and process it from there.
+    // Move the range group's migrated_ranges list to the local_migrated_ranges
+    // list and process it from there.
     uvm_spin_lock(&range_group->migrated_ranges_lock);
     list_replace_init(&range_group->migrated_ranges, &local_migrated_ranges);
     uvm_spin_unlock(&range_group->migrated_ranges_lock);
@@ -404,21 +408,23 @@ static NV_STATUS uvm_range_group_prevent_migration(uvm_range_group_t *range_grou
         uvm_for_each_va_range_in(va_range, va_space, rgr->node.start, rgr->node.end) {
             // VA ranges need to have a preferred location set in order for their
             // range group to be set to non-migratable.
-            if (va_range->preferred_location == UVM_MAX_PROCESSORS) {
+            if (UVM_ID_IS_INVALID(va_range->preferred_location)) {
                 status = NV_ERR_INVALID_ARGUMENT;
                 goto done;
             }
 
-            // If the preferred location is a GPU, check that it's not fault-capable
-            if (va_range->preferred_location != UVM_CPU_ID &&
+            // If the preferred location is a GPU, check that it's not
+            // fault-capable
+            if (UVM_ID_IS_GPU(va_range->preferred_location) &&
                 uvm_processor_mask_test(&va_space->faultable_processors, va_range->preferred_location)) {
                 status = NV_ERR_INVALID_DEVICE;
                 goto done;
             }
 
-            // Check that all UVM-Lite GPUs are able to access the preferred location
+            // Check that all UVM-Lite GPUs are able to access the
+            // preferred location
             if (!uvm_processor_mask_subset(&va_range->uvm_lite_gpus,
-                                           &va_space->accessible_from[va_range->preferred_location])) {
+                                           &va_space->accessible_from[uvm_id_value(va_range->preferred_location)])) {
                 status = NV_ERR_INVALID_DEVICE;
                 goto done;
             }
@@ -551,18 +557,21 @@ NV_STATUS uvm_range_group_assign_range(uvm_va_space_t *va_space, uvm_range_group
 
     uvm_range_group_for_each_range_in(rgr, va_space, start, end) {
         if (rgr->node.start < start && rgr->node.end > end) {
-            // The region described by [start, end] lies entirely within rgr and does not sit on rgr's boundary.
+            // The region described by [start, end] lies entirely within rgr
+            // and does not sit on rgr's boundary.
             NvU64 orig_end = rgr->node.end;
 
-            // Check if the rgr is already part of the specified range group and, if so, do nothing.
+            // Check if the rgr is already part of the specified range group and,
+            // if so, do nothing.
             if (rgr->range_group == range_group) {
                 uvm_range_group_range_destroy(new_rgr);
                 return NV_OK;
             }
 
-            // rgr needs to be split to make room for the new range group range. Do this by first creating a new range
-            // group range called "next" for the region of memory just above new_rgr, then shrink rgr down so that it
-            // fits just below new_rgr.
+            // rgr needs to be split to make room for the new range group range.
+            // Do this by first creating a new range group range called "next"
+            // for the region of memory just above new_rgr, then shrink rgr
+            // down so that it fits just below new_rgr.
             next = range_group_range_create(rgr->range_group, end + 1, orig_end);
             if (next == NULL) {
                 uvm_range_group_range_destroy(new_rgr);
@@ -580,11 +589,13 @@ NV_STATUS uvm_range_group_assign_range(uvm_va_space_t *va_space, uvm_range_group
             uvm_spin_unlock(&rgr->range_group->migrated_ranges_lock);
         }
         else if (rgr->node.start < start) {
-            // The region [start, end] overlaps with the end of rgr. Shrink rgr by moving its end downward.
+            // The region [start, end] overlaps with the end of rgr.
+            // Shrink rgr by moving its end downward.
             uvm_range_tree_shrink_node(&va_space->range_group_ranges, &rgr->node, rgr->node.start, start - 1);
         }
         else if (rgr->node.end > end) {
-            // The region [start, end] overlaps with the begining of rgr. Shring rgr by moving its beginning upward.
+            // The region [start, end] overlaps with the begining of rgr.
+            // Shrink rgr by moving its beginning upward.
             uvm_range_tree_shrink_node(&va_space->range_group_ranges, &rgr->node, end + 1, rgr->node.end);
         }
         else {
