@@ -246,9 +246,7 @@ struct file_operations device_fops =
 #if defined(NV_FILE_OPERATIONS_HAS_IOCTL)
     .ioctl = nvswitch_device_ioctl,
 #endif
-#if defined(NV_FILE_OPERATIONS_HAS_UNLOCKED_IOCTL)
     .unlocked_ioctl = nvswitch_device_unlocked_ioctl,
-#endif
     .open    = nvswitch_device_open,
     .release = nvswitch_device_release,
     .poll    = nvswitch_device_poll
@@ -260,9 +258,7 @@ struct file_operations ctl_fops =
 #if defined(NV_FILE_OPERATIONS_HAS_IOCTL)
     .ioctl = nvswitch_ctl_ioctl,
 #endif
-#if defined(NV_FILE_OPERATIONS_HAS_UNLOCKED_IOCTL)
     .unlocked_ioctl = nvswitch_ctl_unlocked_ioctl,
-#endif
 };
 
 static int nvswitch_initialize_device_interrupt(NVSWITCH_DEV *nvswitch_dev);
@@ -553,6 +549,15 @@ init_device_failed:
     return rc;
 }
 
+static void
+nvswitch_post_init_device
+(
+    NVSWITCH_DEV *nvswitch_dev
+)
+{
+    nvswitch_lib_post_init_device(nvswitch_dev->lib_device);
+}
+
 static void
 nvswitch_deinit_device
 (
@@ -1225,6 +1230,8 @@ nvswitch_probe
         goto init_device_failed;
     }
 
+    nvswitch_post_init_device(nvswitch_dev);
+
     rc = nvswitch_init_background_tasks(nvswitch_dev);
     if (rc)
     {
@@ -1638,6 +1645,19 @@ nvswitch_os_override_platform
 {
 }
 
+NvlStatus
+NVLINK_API_CALL
+nvswitch_os_read_registery_binary
+(
+    void *os_handle,
+    const char *name,
+    NvU8 *data,
+    NvU32 length
+)
+{
+    return -NVL_ERR_NOT_SUPPORTED;
+}
+
 NvU32
 NVLINK_API_CALL
 nvswitch_os_get_device_count
@@ -1761,3 +1781,169 @@ nvswitch_os_read_registry_dword
 
     return NVL_SUCCESS;
 }
+
+NvlStatus
+NVLINK_API_CALL
+nvswitch_os_alloc_contig_memory
+(
+    void **virt_addr,
+    NvU32 size,
+    NvBool force_dma32
+)
+{
+    if (!virt_addr)
+        return -NVL_BAD_ARGS;
+
+    *virt_addr = kmalloc(PAGE_SIZE, GFP_KERNEL | force_dma32 ? GFP_DMA32 : 0);
+
+    if(!*virt_addr)
+    {
+        pr_err("nvidia-nvswitch: unable to allocate kernel memory\n");
+        return -NVL_NO_MEM;
+    }
+
+    return NVL_SUCCESS;
+}
+
+void
+NVLINK_API_CALL
+nvswitch_os_free_contig_memory
+(
+    void *virt_addr
+)
+{
+    kfree(virt_addr);
+}
+
+static inline int
+_nvswitch_to_pci_dma_direction
+(
+    NvU32 direction
+)
+{
+    if (direction == NVSWITCH_DMA_DIR_TO_SYSMEM)
+        return PCI_DMA_FROMDEVICE;
+    else if (direction == NVSWITCH_DMA_DIR_FROM_SYSMEM)
+        return PCI_DMA_TODEVICE;
+    else
+        return PCI_DMA_BIDIRECTIONAL;
+}
+
+NvlStatus
+NVLINK_API_CALL
+nvswitch_os_map_dma_region
+(
+    void *os_handle,
+    void *cpu_addr,
+    NvU64 *dma_handle,
+    NvU32 size,
+    NvU32 direction
+)
+{
+    int dma_dir;
+    struct pci_dev *pdev = (struct pci_dev *)os_handle;
+
+    if (!pdev || !cpu_addr || !dma_handle)
+        return -NVL_BAD_ARGS;
+
+    dma_dir = _nvswitch_to_pci_dma_direction(direction);
+
+    *dma_handle = (NvU64)pci_map_single(pdev, cpu_addr, size, dma_dir);
+
+    if (pci_dma_mapping_error(pdev, *dma_handle))
+    {
+        pr_err("nvidia-nvswitch: unable to create PCI DMA mapping\n");
+        return -NVL_ERR_GENERIC;
+    }
+
+    return NVL_SUCCESS;
+}
+
+NvlStatus
+NVLINK_API_CALL
+nvswitch_os_unmap_dma_region
+(
+    void *os_handle,
+    void *cpu_addr,
+    NvU64 dma_handle,
+    NvU32 size,
+    NvU32 direction
+)
+{
+    int dma_dir;
+    struct pci_dev *pdev = (struct pci_dev *)os_handle;
+
+    if (!pdev || !cpu_addr)
+        return -NVL_BAD_ARGS;
+
+    dma_dir = _nvswitch_to_pci_dma_direction(direction);
+
+    pci_unmap_single(pdev, dma_handle, size, dma_dir);
+
+    return NVL_SUCCESS;
+}
+
+NvlStatus
+NVLINK_API_CALL
+nvswitch_os_set_dma_mask
+(
+    void *os_handle,
+    NvU32 dma_addr_width
+)
+{
+    struct pci_dev *pdev = (struct pci_dev *)os_handle;
+
+    if (!pdev)
+        return -NVL_BAD_ARGS;
+
+    if (pci_set_dma_mask(pdev, DMA_BIT_MASK(dma_addr_width)))
+        return -NVL_ERR_GENERIC;
+
+    return NVL_SUCCESS;
+}
+
+NvlStatus
+NVLINK_API_CALL
+nvswitch_os_sync_dma_region_for_cpu
+(
+    void *os_handle,
+    NvU64 dma_handle,
+    NvU32 size,
+    NvU32 direction
+)
+{
+    int dma_dir;
+    struct pci_dev *pdev = (struct pci_dev *)os_handle;
+
+    if (!pdev)
+        return -NVL_BAD_ARGS;
+
+    dma_dir = _nvswitch_to_pci_dma_direction(direction);
+
+    pci_dma_sync_single_for_cpu(pdev, dma_handle, size, dma_dir);
+
+    return NVL_SUCCESS;
+}
+
+NvlStatus
+NVLINK_API_CALL
+nvswitch_os_sync_dma_region_for_device
+(
+    void *os_handle,
+    NvU64 dma_handle,
+    NvU32 size,
+    NvU32 direction
+)
+{
+    int dma_dir;
+    struct pci_dev *pdev = (struct pci_dev *)os_handle;
+
+    if (!pdev)
+        return -NVL_BAD_ARGS;
+
+    dma_dir = _nvswitch_to_pci_dma_direction(direction);
+
+    pci_dma_sync_single_for_device(pdev, dma_handle, size, dma_dir);
+
+    return NVL_SUCCESS;
+}
